==> console-container-v2.3.5-1.tar.gz: package/useInventory/useInventory.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _typeof = require("@babel/runtime/helpers/typeof");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useInventory = void 0;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _react = require("react");

var reactRouterDom = _interopRequireWildcard(require("react-router-dom"));

var _reactTable = require("@patternfly/react-table");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2["default"])(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

console.error('"useInventory" hook is deprecated and will be removed in v4. Please use Chrome 2.0 compatible Inventory version.');

var useInventory = function useInventory(_ref) {
  var store = _ref.store,
      tableReducer = _ref.tableReducer,
      detailReducer = _ref.detailReducer,
      getRegistry = _ref.getRegistry;
  var cleenupCallback;

  var _useState = (0, _react.useState)({
    newReducers: null,
    rawReducers: null
  }),
      _useState2 = (0, _slicedToArray2["default"])(_useState, 2),
      inventory = _useState2[0],
      setInventory = _useState2[1];

  var _useState3 = (0, _react.useState)({
    InventoryTable: null,
    InventoryDetail: null,
    TagWithDialog: null
  }),
      _useState4 = (0, _slicedToArray2["default"])(_useState3, 2),
      inventoryComponents = _useState4[0],
      setInventoryComponents = _useState4[1];

  (0, _react.useEffect)(function () {
    (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee() {
      var currStore, registry, _yield$insights$loadI, inventoryConnector, INVENTORY_ACTION_TYPES, mergeWithDetail, mergeWithEntities, newReducers, _registry, _registry$getStore, _inventoryConnector, InventoryDetailHead, AppInfo, InventoryTable, InventoryDetail, TagWithDialog, _registry2, _registry2$register;

      return _regenerator["default"].wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              currStore = store;
              _context.next = 3;
              return insights.loadInventory({
                reactRouterDom: reactRouterDom,
                pfReactTable: {
                  Table: _reactTable.Table,
                  TableBody: _reactTable.TableBody,
                  TableHeader: _reactTable.TableHeader,
                  TableGridBreakpoint: _reactTable.TableGridBreakpoint,
                  cellWidth: _reactTable.cellWidth,
                  TableVariant: _reactTable.TableVariant,
                  sortable: _reactTable.sortable,
                  expandable: _reactTable.expandable,
                  SortByDirection: _reactTable.SortByDirection
                }
              });

            case 3:
              _yield$insights$loadI = _context.sent;
              inventoryConnector = _yield$insights$loadI.inventoryConnector;
              INVENTORY_ACTION_TYPES = _yield$insights$loadI.INVENTORY_ACTION_TYPES;
              mergeWithDetail = _yield$insights$loadI.mergeWithDetail;
              mergeWithEntities = _yield$insights$loadI.mergeWithEntities;
              newReducers = {};

              if (tableReducer) {
                newReducers = _objectSpread(_objectSpread({}, newReducers), mergeWithEntities(tableReducer(INVENTORY_ACTION_TYPES)));
              }

              if (detailReducer) {
                newReducers = _objectSpread(_objectSpread({}, newReducers), mergeWithDetail(detailReducer(INVENTORY_ACTION_TYPES)));
              }

              if (getRegistry && typeof getRegistry === 'function') {
                registry = getRegistry();
              }

              if (!currStore && registry) {
                currStore = (_registry = registry) === null || _registry === void 0 ? void 0 : (_registry$getStore = _registry.getStore) === null || _registry$getStore === void 0 ? void 0 : _registry$getStore.call(_registry);
              }

              _inventoryConnector = inventoryConnector(currStore), InventoryDetailHead = _inventoryConnector.InventoryDetailHead, AppInfo = _inventoryConnector.AppInfo, InventoryTable = _inventoryConnector.InventoryTable, InventoryDetail = _inventoryConnector.InventoryDetail, TagWithDialog = _inventoryConnector.TagWithDialog;
              setInventory(function () {
                return {
                  newReducers: newReducers,
                  rawReducers: {
                    mergeWithEntities: mergeWithEntities,
                    mergeWithDetail: mergeWithDetail
                  }
                };
              });

              if (registry) {
                cleenupCallback = (_registry2 = registry) === null || _registry2 === void 0 ? void 0 : (_registry2$register = _registry2.register) === null || _registry2$register === void 0 ? void 0 : _registry2$register.call(_registry2, newReducers);
              }

              setInventoryComponents(function () {
                return {
                  InventoryDetail: {
                    InventoryDetailHead: InventoryDetailHead,
                    AppInfo: AppInfo,
                    InventoryDetail: InventoryDetail
                  },
                  InventoryTable: InventoryTable,
                  TagWithDialog: TagWithDialog
                };
              });

            case 17:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    }))();
    return function () {
      if (cleenupCallback && typeof cleenupCallback === 'function') {
        cleenupCallback();
      }
    };
  }, []);
  return _objectSpread(_objectSpread({}, inventory), inventoryComponents);
};

exports.useInventory = useInventory;

==> console-container-v2.3.10-4.tar.gz: package/useInventory/useInventory.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _typeof = require("@babel/runtime/helpers/typeof");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = exports.useInventory = void 0;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _react = require("react");

var reactRouterDom = _interopRequireWildcard(require("react-router-dom"));

var _reactTable = require("@patternfly/react-table");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2["default"])(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

console.error('"useInventory" hook is deprecated and will be removed in v4. Please use Chrome 2.0 compatible Inventory version.');

var useInventory = function useInventory(_ref) {
  var store = _ref.store,
      tableReducer = _ref.tableReducer,
      detailReducer = _ref.detailReducer,
      getRegistry = _ref.getRegistry;
  var cleenupCallback;

  var _useState = (0, _react.useState)({
    newReducers: null,
    rawReducers: null
  }),
      _useState2 = (0, _slicedToArray2["default"])(_useState, 2),
      inventory = _useState2[0],
      setInventory = _useState2[1];

  var _useState3 = (0, _react.useState)({
    InventoryTable: null,
    InventoryDetail: null,
    TagWithDialog: null
  }),
      _useState4 = (0, _slicedToArray2["default"])(_useState3, 2),
      inventoryComponents = _useState4[0],
      setInventoryComponents = _useState4[1];

  (0, _react.useEffect)(function () {
    (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee() {
      var currStore, registry, _yield$insights$loadI, inventoryConnector, INVENTORY_ACTION_TYPES, mergeWithDetail, mergeWithEntities, newReducers, _registry, _registry$getStore, _inventoryConnector, InventoryDetailHead, AppInfo, InventoryTable, InventoryDetail, TagWithDialog, _registry2, _registry2$register;

      return _regenerator["default"].wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              currStore = store;
              _context.next = 3;
              return insights.loadInventory({
                reactRouterDom: reactRouterDom,
                pfReactTable: {
                  Table: _reactTable.Table,
                  TableBody: _reactTable.TableBody,
                  TableHeader: _reactTable.TableHeader,
                  TableGridBreakpoint: _reactTable.TableGridBreakpoint,
                  cellWidth: _reactTable.cellWidth,
                  TableVariant: _reactTable.TableVariant,
                  sortable: _reactTable.sortable,
                  expandable: _reactTable.expandable,
                  SortByDirection: _reactTable.SortByDirection
                }
              });

            case 3:
              _yield$insights$loadI = _context.sent;
              inventoryConnector = _yield$insights$loadI.inventoryConnector;
              INVENTORY_ACTION_TYPES = _yield$insights$loadI.INVENTORY_ACTION_TYPES;
              mergeWithDetail = _yield$insights$loadI.mergeWithDetail;
              mergeWithEntities = _yield$insights$loadI.mergeWithEntities;
              newReducers = {};

              if (tableReducer) {
                newReducers = _objectSpread(_objectSpread({}, newReducers), mergeWithEntities(tableReducer(INVENTORY_ACTION_TYPES)));
              }

              if (detailReducer) {
                newReducers = _objectSpread(_objectSpread({}, newReducers), mergeWithDetail(detailReducer(INVENTORY_ACTION_TYPES)));
              }

              if (getRegistry && typeof getRegistry === 'function') {
                registry = getRegistry();
              }

              if (!currStore && registry) {
                currStore = (_registry = registry) === null || _registry === void 0 ? void 0 : (_registry$getStore = _registry.getStore) === null || _registry$getStore === void 0 ? void 0 : _registry$getStore.call(_registry);
              }

              _inventoryConnector = inventoryConnector(currStore), InventoryDetailHead = _inventoryConnector.InventoryDetailHead, AppInfo = _inventoryConnector.AppInfo, InventoryTable = _inventoryConnector.InventoryTable, InventoryDetail = _inventoryConnector.InventoryDetail, TagWithDialog = _inventoryConnector.TagWithDialog;
              setInventory(function () {
                return {
                  newReducers: newReducers,
                  rawReducers: {
                    mergeWithEntities: mergeWithEntities,
                    mergeWithDetail: mergeWithDetail
                  }
                };
              });

              if (registry) {
                cleenupCallback = (_registry2 = registry) === null || _registry2 === void 0 ? void 0 : (_registry2$register = _registry2.register) === null || _registry2$register === void 0 ? void 0 : _registry2$register.call(_registry2, newReducers);
              }

              setInventoryComponents(function () {
                return {
                  InventoryDetail: {
                    InventoryDetailHead: InventoryDetailHead,
                    AppInfo: AppInfo,
                    InventoryDetail: InventoryDetail
                  },
                  InventoryTable: InventoryTable,
                  TagWithDialog: TagWithDialog
                };
              });

            case 17:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    }))();
    return function () {
      if (cleenupCallback && typeof cleenupCallback === 'function') {
        cleenupCallback();
      }
    };
  }, []);
  return _objectSpread(_objectSpread({}, inventory), inventoryComponents);
};

exports.useInventory = useInventory;
var _default = useInventory;
exports["default"] = _default;
